@@ -192,7 +192,7 @@ es-graphite-dynamic.pl - Dynamically gather metrics and send to graphite
 
 =head1 VERSION
 
-version 3.6
+version 3.7
 
 =head1 SYNOPSIS
 
@@ -237,7 +237,7 @@ From CLI::Helpers:
 
     --data-file         Path to a file to write lines tagged with 'data => 1'
     --color             Boolean, enable/disable color, default use git settings
-    --verbose           Incremental, increase verbosity (Alias is -v)
+    --verbose           Incremental, increase verbosity
     --debug             Show developer output
     --quiet             Show no output (for cron)
 
